@@ -291,7 +291,7 @@ Str& Str::operator= (double num)
 
 void Str::nset(const char* chars, int len)
 {
-    assert(chars);
+    sabassert(chars);
     remove_();
     byteLength_ = len;
     text_ = claimMemory(len + 1);
@@ -301,7 +301,7 @@ void Str::nset(const char* chars, int len)
 
 char Str::operator[] (int index) const
 {
-    assert(index >= 0 && index <= length());
+    sabassert(index >= 0 && index <= length());
     pack_();
     return text_[index];
 }
@@ -459,7 +459,10 @@ char* Str::cloneData()
 {
   pack_();
   char *ret = new char[length() + 1];
-  strcpy(ret, text_);
+  if 
+    (text_) strcpy(ret, text_);
+  else 
+    *ret = 0;
   return ret;
 }
 
@@ -518,7 +521,7 @@ DStr& DStr::operator=(const DStr& other)
 
 DStr& DStr::nadd(const char *adding, int len)
 {
-    assert(adding);
+    sabassert(adding);
     if (text_)
         blocks.nadd(adding, len);
     else
@@ -993,5 +996,34 @@ void UriList::addUri(Phrase what) {
   if (i == -1) append(what);
 }
 
+/************************************/
+/* SortedStringList */
+
+int SortedStringList::compare(int i, int j, void * data)
+{
+  return ((*this)[i] -> compare(*((*this)[j])));
+}
 
 
+int SortedStringList::findIdx(Str & val)
+{
+  int i, j, cmp, result;
+  i = 0; 
+  j = nItems - 1;
+  result = -1;
+
+  while (i <= j) {
+    int x = (int)((i + j) / 2);
+    cmp = (*this)[x] -> compare(val);
+    if (cmp < 0) {
+      i = x + 1;
+    } else if (cmp > 0) {
+      j = x - 1;
+    } else {
+      result = x;
+      break;
+    }
+  }
+
+  return result;
+}
