@@ -513,7 +513,7 @@ public:
     SList(int logBlocksize_);
         // comparison of two elements
     virtual int compare(int, int, void *data)
-    { assert(!"abstract compare"); return 0; }
+    { sabassert(!"abstract compare"); return 0; }
         // insertion of an element
     void insert(T, void *data = NULL);
     void sort(int from = 0, int to = - 1, void *data = NULL);  // to == -1 means "nItems-1"
@@ -616,7 +616,7 @@ void List<T>::append(T what)
             blocksize = origBlocksize;
             block = (T*) claimMemory(blocksize * sizeof(T));
             // FIXME: asserting memory request ok
-            assert(block);
+            sabassert(block);
         }
     }
     block[nItems++] = what;
@@ -625,7 +625,7 @@ void List<T>::append(T what)
 template <class T>
 void List<T>::deppend()
 {
-    assert (nItems > 0);
+    sabassert (nItems > 0);
     --nItems;
     if (!(nItems & (nItems - 1)) && (nItems >= origBlocksize))   // realloc at powers of 2
     {
@@ -636,7 +636,7 @@ void List<T>::deppend()
             block = (T*) reclaimMemory(block, blocksize * sizeof(T),
                 oldblocksize * sizeof(T));
             // FIXME: asserting memory request ok
-            assert(block);
+            sabassert(block);
         }
         else
             returnMemory(block);
@@ -653,13 +653,13 @@ void List<T>::grow()
     int nbytes = blocksize * sizeof(T);
     block = (T*) reclaimMemory(block, nbytes, nbytes >> 1);
     // FIXME: asserting memory request ok
-    assert(block);
+    sabassert(block);
 }
 
 template <class T>
 void List<T>::rm(int n)
 {
-    assert((n >= 0) && (n < nItems));
+    sabassert((n >= 0) && (n < nItems));
     memmove(block + n, block + n + 1, (nItems - n - 1) * sizeof(T));
     deppend();
 }
@@ -667,8 +667,8 @@ void List<T>::rm(int n)
 template <class T>
 void List<T>::swap(int i, int j)
 {
-    assert((i >= 0) && (i < nItems));
-    assert((j >= 0) && (j < nItems));
+    sabassert((i >= 0) && (i < nItems));
+    sabassert((j >= 0) && (j < nItems));
     T temp = block[i];
     block[i] = block[j];
     block[j] = temp;
@@ -701,14 +701,14 @@ List<T>::~List()
 template <class T>
 inline T& List<T>::operator[](int ndx) const
 {
-    assert((ndx < nItems) && (ndx >= 0));
+    sabassert((ndx < nItems) && (ndx >= 0));
     return block[ndx];
 };
 
 template <class T>
 inline T& List<T>::last() const
 {
-    assert(nItems);
+    sabassert(nItems);
     return block[nItems - 1];
 }
 
@@ -758,7 +758,7 @@ void PList<T>::freeall(Bool asArray)
 template <class T>
 void PList<T>::freerm(int n, Bool asArray)
 {
-    assert((n >= 0) && (n < this->nItems));
+    sabassert((n >= 0) && (n < this->nItems));
     deleteScalarOrVector(this->block[n], asArray);
     this->rm(n);
 }
@@ -836,7 +836,7 @@ void SList<T>::qsPartition(int& bottom, int& top, void *data)
 template <class T>
 void SList<T>::quicksort(int bottom, int top, void *data)
 {
-    assert(QSORT_THRESHOLD >= 3);
+    sabassert(QSORT_THRESHOLD >= 3);
     int i = bottom, j = top;
     if (top - bottom < QSORT_THRESHOLD)
         insertsort(bottom, top, data);
