@@ -59,7 +59,7 @@ Bool cmpNames(Sit S, NodeHandle v, NodeHandle w)
 Bool similarVerts(Sit S, NodeHandle v, NodeHandle w)
 {
   //some optimalization for native node may be done (compare QNames)
-  assert(!nhNull(v) && !nhNull(w));
+  sabassert(!nhNull(v) && !nhNull(w));
   SXP_NodeType typeV = S.dom().getNodeType(v);
   // vertices of different types don't match
   if (typeV != S.dom().getNodeType(w) )
@@ -89,7 +89,7 @@ Bool similarVerts(Sit S, NodeHandle v, NodeHandle w)
 
 NodeHandle gotoPreceding(Sit S, NodeHandle v, Bool siblingOnly)
 {
-    assert(v);
+    sabassert(v);
     switch(S.dom().getNodeType(v))
     {
     case DOCUMENT_NODE:
@@ -223,7 +223,7 @@ void getFTokenParams(const Str& fmt, char& type, int& width)
     type = '1';
     width = 1;
     int len = utf8StrLength(fmt);
-    assert(len);
+    sabassert(len);
     if (len > 1 && fmt[0] != '0') return; // with default values
     switch(fmt[0])
     {
@@ -448,5 +448,3 @@ eFlag xslNumberFormat(
     result = tempResult;
     return OK;
 }
-
-
