@@ -266,8 +266,8 @@ These deletes are now subsumed in "datalines.freeall()":
     freeNonArgDatalines();
     if (Sp && !Sp -> isError())
       {
-        assert(modes.isEmpty());
-        assert(outputters_.isEmpty());
+        sabassert(modes.isEmpty());
+        sabassert(outputters_.isEmpty());
       }
     else
       {
@@ -368,7 +368,7 @@ eFlag Processor::run(Sit S, const char* resultURI, NodeHandle doc /*= NULL */)
     //check statuses
     //this is not needed, 
     //cleanupAfterRun takes care in the case of error
-    //assert(!outputters_.number());
+    //sabassert(!outputters_.number());
 
     Log1(S, L1_EXECUTION_DONE, getMillisecsDiff(time_was));
     return OK;
@@ -690,7 +690,7 @@ eFlag Processor::startDocument(Sit S, OutputDocument *doc)
   switch (doc -> getState()) {
   case OUTDOC_ACTIVE:
     {
-      assert(!"rewrite document");
+      sabassert(!"rewrite document");
       //printf("---> aaa\n");
       //OutputterObj *out = NZ( doc -> getOutputter());
       //E( pushOutputter(S, out) );
@@ -736,7 +736,7 @@ eFlag Processor::startDocument(Sit S, OutputDocument *doc)
       doc -> setState(OUTDOC_ACTIVE);
     }; break;
   case OUTDOC_FINISHED:
-    assert(! "Couldn't write the document twice"); break;
+    sabassert(! "Couldn't write the document twice"); break;
   }
   return OK;
 }
@@ -746,7 +746,7 @@ eFlag Processor::finishDocument(Sit S, OutputDocument *doc, Bool canClose)
   switch (doc -> getState()) {
   case OUTDOC_NEW:
   case OUTDOC_FINISHED:
-    assert(!"Could not finish unopened/finished document"); break;
+    sabassert(!"Could not finish unopened/finished document"); break;
   case OUTDOC_ACTIVE:
     {
       E( doc -> finish(S) );
@@ -990,7 +990,7 @@ void Processor::copyArg(Sit S, const Str& argName, int* argOrdinal,
 
 eFlag Processor::useArg(Sit S, const char *name, const char *val)
 {
-    assert(name);
+    sabassert(name);
     DStr nameStr;
     if (*name != '/')
         nameStr = "/";
@@ -1011,7 +1011,7 @@ eFlag Processor::useArg(Sit S, const char *name, const char *val)
 
 eFlag Processor::useTree(Sit S, const char *name, Tree *t)
 {
-  assert(name);
+  sabassert(name);
   DStr nameStr;
   if (*name != '/')
     nameStr = "/";
@@ -1029,7 +1029,7 @@ eFlag Processor::useTree(Sit S, const char *name, Tree *t)
 
 eFlag Processor::addGlobalParam(Sit S, const char *name, const char *val)
 {
-    assert(name);
+    sabassert(name);
     if (!val) val = (char*)"";
     globalParamsList.appendConstruct(name, val);
     return OK;
@@ -1037,7 +1037,7 @@ eFlag Processor::addGlobalParam(Sit S, const char *name, const char *val)
 
 eFlag Processor::useGlobalParam(Sit S, const char *name, const char *val)
 {
-    assert(name);
+    sabassert(name);
     QName q;
     q.setLocal(NZ(styleSheet) -> unexpand(name));
     Expression *expr = new Expression(styleSheet -> getRoot(), EXF_ATOM);
@@ -1166,9 +1166,9 @@ Str Processor::getAliasedName(const EQName& name,
 	  //we should proceed w/o this 
 	  //currNamespaces.appendConstruct(name.getPrefix(),name.getUri(),TRUE);
 	  //currNamespaces.appendConstruct(newPrefixStr,
-	  //*currNamespaces.getUri(newPrefixStr));
+	  // *currNamespaces.getUri(newPrefixStr));
 	};
-      //if (!s.isEmpty()) // could be empty e.g. for the default namespace
+	//if (!s.isEmpty()) //could be empty e.g. for the default namespace
       //  s += ":";
    };
    if (expatLike)
@@ -1256,7 +1256,7 @@ eFlag Processor::evaluateJavaScript(Sit S, Str &uri, DStr &script)
   //printf("===> evaluating uri %s: %s\n", (char*)uri, (char*)script);
 
   JSContextItem *item = jscontexts.find(uri, TRUE);
-  assert(item);
+  sabassert(item);
   if (item && item -> cx) {
     if (! SJSEvaluate(*item, script ) )
       {
@@ -1449,7 +1449,7 @@ Bool Processor::isInBinding()
 eFlag Processor::pushDocumentDefinition(Sit S, OutputDefinition *def,
 					OutputterObj*& out)
 {
-  assert(def);
+  sabassert(def);
   Bool change = !documentDefinitions.number() || 
     documentDefinitions.last() != def;
 
@@ -1469,7 +1469,7 @@ eFlag Processor::pushDocumentDefinition(Sit S, OutputDefinition *def,
 
 eFlag Processor::popDocumentDefinition(Sit S)
 {
-  assert(documentDefinitions.number());
+  sabassert(documentDefinitions.number());
   OutputDefinition *last = documentDefinitions.last();
   documentDefinitions.deppend();
   //
