@@ -42,6 +42,7 @@
 #include "tree.h"
 #include "context.h"
 #include "guard.h"
+#include "platform.h"
 
 #define getTmpList(v) (toV(v) -> getOwner().tmpList)
 
@@ -178,7 +179,7 @@ SDOM_Exception __SDOM_swallowParentNS(SablotSituation s, SDOM_Node n)
   // do it recursively for all child elements
     if ( n && isElement(toV(n)) && toE(n) -> parent ) {
       NSList* parentNs = &(toE(toE(n) -> parent) -> namespaces);
-      Tree* t = toTree( n );
+      Tree* t = toTree(ownerDoc(toE(n)));
       SE( ___SDOM_swallowParentNSrec(s, n, t, parentNs) );
     };
     return SDOM_OK;
@@ -197,7 +198,8 @@ SDOM_Exception __SDOM_dropParentNS(SablotSituation s, SDOM_Node n)
 	if ( nm -> usageCount == 0 && nm -> kind == NSKIND_PARENT ) {
 	  checkedNs->rm(i);
 	  nm -> parent = NULL;
-	  getTmpList(toE(n)).append(nm);
+	  //getTmpList(toE(n)).append(nm);
+	  delete nm;
 	};
       };
       SDOM_Node checkedNode;
@@ -354,14 +356,14 @@ SDOM_Exception SDOM_createElementNS(SablotSituation s, SDOM_Document d, SDOM_Nod
         if ( !uri ) 
 	    return SDOM_NAMESPACE_ERR;  
 
-	prefix.nset((char*)qName, (int)colon - (int)qName);
+	prefix.nset((char*)qName, intPtrDiff(colon, qName));
 
 	if ( !strcmp((const char*)prefix,"xml") && strcmp(theXMLNamespace,uri) )
 	    //redefinition of xml-namespace
 	    return SDOM_NAMESPACE_ERR;
 
 	q.setPrefix(toE(d)->dict().insert((const char*)prefix));
-	q.setLocal(toE(d)->dict().insert((const char*)((int)colon + 1)));
+	q.setLocal(toE(d)->dict().insert((const char*)((ptrdiff_t)colon + 1)));
 	q.setUri(toE(d)->dict().insert((const char*)uri));
 
     } else {
@@ -439,7 +441,7 @@ SDOM_Exception SDOM_createAttributeNS(SablotSituation s, SDOM_Document d, SDOM_N
         if ( !uri )
 	    return SDOM_NAMESPACE_ERR;
 
-	prefix.nset((char*)qName, (int)colon - (int)qName);
+	prefix.nset((char*)qName, intPtrDiff(colon, qName));
 
 	if ( !strcmp((const char*)prefix,"xml") && strcmp(theXMLNamespace,uri) )
 	    //redefinition of xml namespace
@@ -450,7 +452,7 @@ SDOM_Exception SDOM_createAttributeNS(SablotSituation s, SDOM_Document d, SDOM_N
 	    return SDOM_NAMESPACE_ERR;
 
 	q.setPrefix(toE(d)->dict().insert((const char*)prefix));
-	q.setLocal(toE(d)->dict().insert((const char*)((int)colon + 1)));
+	q.setLocal(toE(d)->dict().insert((const char*)((ptrdiff_t)colon + 1)));
 	q.setUri(toE(d)->dict().insert((const char*)uri));
 
     } else {
@@ -547,7 +549,7 @@ SDOM_Exception SDOM_disposeNode(SablotSituation s, SDOM_Node n)
 	    case VT_COMMENT:
 	        ccdelete(v, toComment(v)); break;
 		default:
-		    assert(!"disposeSDOM_Node");	    
+		    sabassert(!"disposeSDOM_Node");	    
     }
     return SDOM_OK;
 }
@@ -1078,7 +1080,7 @@ SDOM_Exception SDOM_removeChild(SablotSituation s, SDOM_Node n, SDOM_Node oldChi
 	if (toV(oldChild) -> parent != toV(n))
 	    SDOM_Err(s, SDOM_NOT_FOUND_ERR);
 	//_JP_ v
-	SE( __SDOM_dropParentNS(s, oldChild) );
+	//SE( __SDOM_dropParentNS(s, oldChild) );
 	//_JP_ ^
 	toE(v) -> removeChild(toV(oldChild));
 	//_TH_ v
@@ -1195,7 +1197,7 @@ SDOM_Exception cloneVertex(SablotSituation s, Tree *t, Vertex *foreign, int deep
     if (isElement(foreign))
     {
         // must clone atts and namespaces in any case
-	    assert(isElement(*clone));
+	    sabassert(isElement(*clone));
         cloneVertexList(s, t, &(toE(foreign) -> atts), deep, toE(*clone));
         cloneVertexList(s, t, &(toE(foreign) -> namespaces), deep, toE(*clone));
 	    
@@ -1444,7 +1446,7 @@ SDOM_Exception SDOM_setAttributeNS(SablotSituation s, SDOM_Node n, const SDOM_ch
         if ( !uri ) 
 	    SDOM_Err(s, SDOM_NAMESPACE_ERR);  
 
-	prefix.nset((char*)qName, (int)colon - (int)qName);
+	prefix.nset((char*)qName, intPtrDiff(colon, qName));
 
 	if ( !strcmp((const char*)prefix,"xml") && strcmp(theXMLNamespace,uri) )
 	    //redefinition of xml-namespace
@@ -1455,7 +1457,7 @@ SDOM_Exception SDOM_setAttributeNS(SablotSituation s, SDOM_Node n, const SDOM_ch
 	    SDOM_Err(s, SDOM_NAMESPACE_ERR);
 
 	q.setPrefix(ownerDoc(toE(n))->dict().insert((const char*)prefix));
-	q.setLocal(ownerDoc(toE(n))->dict().insert((const char*)((int)colon + 1)));
+	q.setLocal(ownerDoc(toE(n))->dict().insert((const char*)((ptrdiff_t)colon + 1)));
 	q.setUri(ownerDoc(toE(n))->dict().insert((const char*)uri));
 
     } else {
@@ -1500,8 +1502,9 @@ SDOM_Exception SDOM_setAttributeNS(SablotSituation s, SDOM_Node n, const SDOM_ch
 			     q.getPrefix(), 
 			     q.getUri(),
 			     NSKIND_PARENT, 0) );
-	replaced = new(&(toTree(ownerDoc(e)) -> getArena())) 
-	           Attribute(*toTree(ownerDoc(e)), q, (char*)"", XSLA_NONE);
+	Tree *tOwner = toTree(ownerDoc(e));
+	replaced = new(&(tOwner -> getArena())) 
+	           Attribute(*tOwner, q, (char*)"", XSLA_NONE);
 	e -> atts.append(toA(replaced));
 	toV(replaced) -> setParent(e);
       };
