@@ -192,10 +192,14 @@ eFlag StylesheetStructure::findBestRule(
 XSLElement* StylesheetStructure::findRuleByName(Tree &t, QName &q)
 {
     XSLElement* ret = rulesList.findByName(t,q);
-    int importCount = importChildren.number(),
-	i;
-    for (i = 0; !ret && i < importCount; i++)
-	ret = importChildren[i] -> rulesList.findByName(t,q);
+    if (! ret)
+      {
+	int importCount = importChildren.number(),
+	  i;
+	for (i = 0; !ret && i < importCount; i++)
+	  ret = importChildren[i] -> findRuleByName(t,q);
+	  //ret = importChildren[i] -> rulesList.findByName(t,q);
+      }
     return ret;
 }
 
@@ -306,7 +310,7 @@ eFlag VarDirectory::insert(Sit S, QName &name, XSLElement* var)
 	    oldPrec = (*this)[i] -> getElement() -> getImportPrecedence(),
 	    newPrec = var -> getImportPrecedence();
 	// due to immediate resolution of xsl:import, new must be <= old
-	assert(newPrec <= oldPrec);
+	sabassert(newPrec <= oldPrec);
 	(*this)[i] -> setElement(var);
 	if (newPrec == oldPrec)
 	{
@@ -505,7 +509,7 @@ int AttSetList::findNdx(const QName &what) const
 void AliasItem::set(Phrase newKey, Phrase newValue, Phrase newPrefix,
 		    int newPrecedence, XSLElement *source)
 {
-    assert(newPrecedence >= 0);
+    sabassert(newPrecedence >= 0);
     if (key == UNDEF_PHRASE) key = newKey;
     if (precedence == newPrecedence && value != newValue && !redefinition)
 	redefinition = source;
@@ -609,7 +613,9 @@ Tree::~Tree()
     unparsedEntities.freeall(FALSE);
     
     pendingNSList.freelast(FALSE);
-    //assert(!pendingNSList.number());
+    //sabassert(!pendingNSList.number());
+	//tmpList must be empty before the arena gets down automatically
+	tmpList.freeall(FALSE);
 }
 
 void Tree::initDict()
@@ -651,8 +657,8 @@ void Tree::flushPendingText()
     
 eFlag Tree::appendVertex(Sit S, Vertex *v)
 {
-    assert(stackTop && isDaddy(stackTop));
-    assert(!isText(v) || !pendingTextNode);
+    sabassert(stackTop && isDaddy(stackTop));
+    sabassert(!isText(v) || !pendingTextNode);
     if (!isText(v))
         flushPendingText();
     E( cast(Daddy*,stackTop) -> newChild(S, v) ); //sets parent too
@@ -666,9 +672,9 @@ eFlag Tree::appendVertex(Sit S, Vertex *v)
 
 void Tree::dropCurrentElement(Vertex *v)
 {
-    assert(stackTop && isElement(stackTop));
-    assert(stackTop == v);
-    assert(!pendingTextNode);
+    sabassert(stackTop && isElement(stackTop));
+    sabassert(stackTop == v);
+    sabassert(!pendingTextNode);
     stackTop = v -> parent;
     delete v;
     toE(stackTop) -> contents.deppend();
@@ -949,9 +955,9 @@ eFlag Tree::processVertexAfterParse(Sit S, Vertex *v, TreeConstructer* tc)
 	    dropCurrentElement(v);
 	    
 	    OutputterObj source;
-	    // we start a subtree to record where the nodes come from
-	    // when including, we use the old structure
-	    // when importing, Tree creates a new one
+	    //we start a subtree to record where the nodes come from
+	    //when including, we use the old structure
+	    //when importing, Tree creates a new one
 	    E( startSubtree(S, (*srcTree).getURI(), theOp) );
 	    //set extension namespaces for subtree
 
@@ -1088,7 +1094,7 @@ eFlag Tree::processVertexAfterParse(Sit S, Vertex *v, TreeConstructer* tc)
 	    XSLElement *son;
 	    for (int i = 0; i < x -> contents.number(); i++)
 	      {
-		assert(isXSLElement(x -> contents[i]) && 
+		sabassert(isXSLElement(x -> contents[i]) && 
 		       toX(x -> contents[i]) -> op == XSL_ATTRIBUTE);
 		son = toX(x -> contents[i]);
 		E( son -> setLogical(S, name, 
@@ -1322,8 +1328,8 @@ Element* Tree::findStylesheet(Daddy& d)
 
 double Tree::defaultPriorityLP(Expression *lpath)
 {
-    assert(lpath && lpath -> functor == EXF_LOCPATH);
-    assert(lpath -> args.number());
+    sabassert(lpath && lpath -> functor == EXF_LOCPATH);
+    sabassert(lpath -> args.number());
     if ((lpath -> args.number() > 1) || lpath -> args[0] -> step -> preds.number())
         return .5;
     else
@@ -1384,7 +1390,7 @@ double Tree::defaultPriority(XSLElement *tmpl)
         }; break;
     default:
         {
-            assert(!"expression not a union or LP");
+            sabassert(!"expression not a union or LP");
             return 0;   // dummy
         }
     };
@@ -1417,35 +1423,38 @@ Bool Tree::isExtensionUri(Phrase uri)
 
 eFlag Tree::insertRule(Sit S, XSLElement *tmpl)
 {
-    double prio;
-    Attribute *a = tmpl -> atts.find(XSLA_PRIORITY);
-    if (!a)
-        prio = defaultPriority(tmpl);
-    else
+  double prio;
+  Attribute *a = tmpl -> atts.find(XSLA_PRIORITY);
+  if (!a)
+    prio = defaultPriority(tmpl);
+  else
     {
-        if (a -> cont.toDouble(prio))
-            Err(S, ET_BAD_NUMBER);
+      if (a -> cont.toDouble(prio))
+	Err(S, ET_BAD_NUMBER);
     };
-    QName q; 
-    GP( QName ) mode = NULL;
-    if (!!(a = tmpl -> atts.find(XSLA_NAME)))
-        E( tmpl -> setLogical(S, q, a -> cont, FALSE) );
-    if (q.getLocal() != UNDEF_PHRASE && 
-        subtrees.getCurrent() -> getStructure() -> rules().findByName(
-	    *this, q))
+  QName q; 
+  GP( QName ) mode = NULL;
+  
+  if (!!(a = tmpl -> atts.find(XSLA_NAME)))
+    E( tmpl -> setLogical(S, q, a -> cont, FALSE) );
+  
+  if (q.getLocal() != UNDEF_PHRASE && 
+      subtrees.getCurrent() -> getStructure() -> 
+      rules().findByName(*this, q))
     {
-	Str fullName;
-	expandQStr(q, fullName);
-
-	Err1(S, ET_DUPLICATE_RULE_NAME, fullName);
+      Str fullName;
+      expandQStr(q, fullName);
+      
+      Err1(S, ET_DUPLICATE_RULE_NAME, fullName);
     };
-    if (!!(a = tmpl -> atts.find(XSLA_MODE)))
-        E( tmpl -> setLogical(S, *(mode = new QName), 
-			      a -> cont, FALSE) );
-    
-    subtrees.getCurrent() -> getStructure() -> rules().insert(
-	new RuleItem(tmpl,prio,q,mode.keep()));
-    return OK;
+  
+  if (!!(a = tmpl -> atts.find(XSLA_MODE)))
+    E( tmpl -> setLogical(S, *(mode = new QName), 
+			  a -> cont, FALSE) );
+  
+  subtrees.getCurrent() -> getStructure() -> 
+    rules().insert(new RuleItem(tmpl,prio,q,mode.keep()));
+  return OK;
 }
 
 eFlag Tree::insertAttSet(Sit S, XSLElement *tmpl)
@@ -1583,7 +1592,7 @@ XSLElement* Tree::findRuleByName(QName &q)
 /*
 eFlag Tree::resolveGlobals(Sit S, Context *c, Processor *proc)
 {
-    assert(proc);
+    sabassert(proc);
     QName temp;
     for (int i = 0; i < toplevelVars.number(); i++)
     {
@@ -1620,14 +1629,33 @@ eFlag Tree::popPendingNS(Sit S)
   return OK;
 }
 
-/*
 void Tree::speakDebug()
 {
   DStr foo;
   getRoot().speak(foo, (SpeakMode)(SM_OFFICIAL | SM_INS_SPACES));
   printf("--------------------\n%s\n--------------------\n", (char*)foo);
 }
-*/
+
+void Tree::dumpStructure(Sit S)
+{
+  S.message(MT_LOG, L_SHEET_STRUCTURE, "", "");
+  for (int i = 0; i < subtrees.number(); i++)
+    {
+      //count level
+      DStr out = "";
+      int level = 0;
+      SubtreeInfo * si = subtrees[i];
+      while (si)
+	{
+	  if (level > 0) out += "  ";
+	  level++;
+	  si = si -> getParentSubtree();
+	}
+      
+      out += subtrees[i] -> getBaseURI();
+      S.message(MT_LOG, L_SHEET_ITEM, out, "");
+    }
+}
 
 //_TH_ v
 /****************************************
