@@ -37,6 +37,7 @@
 #include "uri.h"
 #include <string.h>
 #include "proc.h"
+#include "platform.h"
 
 // GP: clean
 
@@ -59,6 +60,24 @@
 #define slashes "/\\"
 #define isSlash(c) (c == '/' || c == '\\')
 
+//special name reporting under windows
+#ifdef __WIN_TOOLS
+#define winName(name) ((name[0] == '/' && name[2] == ':') ? name + 1 : name)
+#else
+#define winName(name) name
+#endif
+
+/*****************************************************************
+uriHasAuthority
+
+  decides, whether given schema should contain the authority
+*****************************************************************/
+
+Bool uriHasAuthority(Str & scheme)
+{
+  return (scheme == (const char*)"file");
+}
+
 /*****************************************************************
 splitBy
 
@@ -102,8 +121,9 @@ void splitURI(const char *uri, FiveStr &parts)
     if (isSlash(*rest) && isSlash(rest[1]))
         RF( c = splitBy(rest += 2, slashes"?#", parts[U_AUTH]) );
     if (isSlash(c) || c == 'A')
-        // extract the path
-        RF( c = splitBy(rest -= (isSlash(c)), "?#", parts[U_PATH]) );
+      // extract the path
+      RF( c = splitBy(rest -= (isSlash(c)), "?#", parts[U_PATH]) );
+    //query and fragment
     if (c == '?')
         // extract the query
         RF( c = splitBy(rest, "#", parts[U_QUERY]) );
@@ -113,16 +133,17 @@ void splitURI(const char *uri, FiveStr &parts)
 
 void joinURI(DStr &joined, FiveStr &parts, Bool schemeToo)
 {
-    joined.empty();
-    if (schemeToo && !parts[U_SCHEME].isEmpty())
-        joined = parts[U_SCHEME] + ":";
-    if (!parts[U_AUTH].isEmpty())
-        joined += Str("//") + parts[U_AUTH];            // add authority
-    joined += parts[U_PATH];                // add path
-    if (!parts[U_QUERY].isEmpty())          // add query
-        joined += Str("?") + parts[U_QUERY];
-    if (!parts[U_FRAG].isEmpty())           // add fragment
-        joined += Str("#") + parts[U_FRAG];
+  joined.empty();
+  if (schemeToo && !parts[U_SCHEME].isEmpty())
+    joined = parts[U_SCHEME] + ":";
+  //if (!parts[U_AUTH].isEmpty())
+  if (uriHasAuthority(parts[U_SCHEME]))
+    joined += Str("//") + parts[U_AUTH];  // add authority
+  joined += parts[U_PATH];                // add path
+  if (!parts[U_QUERY].isEmpty())          // add query
+    joined += Str("?") + parts[U_QUERY];
+  if (!parts[U_FRAG].isEmpty())           // add fragment
+    joined += Str("#") + parts[U_FRAG];
 }
 
 /*****************************************************************
@@ -146,6 +167,7 @@ URIScheme schemeToURI_(Sit S, Str& scheme)
     }
 }
 
+
 /*****************************************************************
 cutLast()
 
@@ -303,18 +325,18 @@ URIScheme makeAbsoluteURI2(Sit S, const char* uri,
 URIScheme makeAbsoluteURI(Sit S, const char* uri,
 			  const char* base, Str& absolute)
 {
-    Str scheme;
-    URIScheme temp;
-    temp = makeAbsoluteURI2(S, uri, base, absolute, scheme);
-    absolute = (scheme + ":") + absolute;
-    return temp;
+  Str scheme;
+  URIScheme temp;
+  temp = makeAbsoluteURI2(S, uri, base, absolute, scheme);
+  absolute = (scheme + ":") + absolute;
+  return temp;
 }
 
 
 URIScheme uri2SchemePath(Sit S, const char *absolute, Str& scheme, Str& rest)
 {
     Bool found = (Bool) !!splitBy(absolute, ":", scheme);
-    assert(found);
+    sabassert(found);
     rest = (char*) absolute;
 /*
  *    if (isSlash(*absolute) && isSlash(absolute[1]))
@@ -410,7 +432,7 @@ _mode       the access mode (DLMODE_READ, DLMODE_WRITE)
 eFlag DataLine::open(Sit S, const char *_uri, DLAccessMode _mode, 
 		     StrStrList* argList_, Bool ignoreErr /* = FALSE */)
 {
-    assert(mode == DLMODE_NONE);  // the buffer must not be open yet
+    sabassert(mode == DLMODE_NONE);  // the buffer must not be open yet
     // combine _uri and _baseUri into one
     Str strScheme, strPath;
     scheme = uri2SchemePath(S, _uri, strScheme, strPath);
@@ -427,11 +449,11 @@ eFlag DataLine::open(Sit S, const char *_uri, DLAccessMode _mode,
                 name += 2;          // skipping the "//" in front
             // try to open the file
 #ifdef _MSC_VER
-            if (!(f = stdopen(name,_mode == DLMODE_WRITE ? "wb" : "rt")))
+            if (!(f = stdopen(name,_mode == DLMODE_WRITE ? "wb" : "rb")))
 #else
             if (!(f = stdopen(name,_mode == DLMODE_WRITE ? "w" : "r")))
 #endif
-                specErr1(S, E_FILE_OPEN, name);
+                specErr1(S, E_FILE_OPEN, winName(name));
             // set fileIsStd if filename is "stdin", "stdout" or "stderr"
             fileIsStd = isstd(name);
         }; break;
@@ -501,12 +523,12 @@ DataLine::close()
 *****************************************************************/
 eFlag DataLine::close(Sit S)
 {
-    assert(mode != DLMODE_NONE);
+    sabassert(mode != DLMODE_NONE);
     switch(scheme)
     {
     case URI_FILE:
         {
-            assert(f);
+            sabassert(f);
             if (!fileIsStd)
             {
 	      if (fclose(f))
@@ -550,19 +572,19 @@ int my_wcslen(const char *p)
 
 eFlag DataLine::save(Sit S, const char *data, int length)
 {
-    assert(mode == DLMODE_WRITE); // assume the file open for writing
+    sabassert(mode == DLMODE_WRITE); // assume the file open for writing
     // int length = utf16Encoded ? my_wcslen(data) : strlen(data);
     switch (scheme)             // choose the output procedure 
     {
     case URI_FILE:              // file: scheme
         {
-            assert(f);          // the file must be open
+            sabassert(f);          // the file must be open
             // fputs(data, f);
             fwrite(data, 1, length, f);
         }; break;
     case URI_ARG:               // arg: scheme
         {
-            assert(outBuf);     // the output buffer must exist
+            sabassert(outBuf);     // the output buffer must exist
             outBuf -> nadd(data, length); 
         }; break;
     case URI_EXTENSION:         // external handler
@@ -600,18 +622,18 @@ is16    TRUE iff the string is UTF-16
 int DataLine::get(Sit S, char *dest,int maxcount)
 {
     int result = 0;
-    assert(mode == DLMODE_READ);  // assume the file open for reading
+    sabassert(mode == DLMODE_READ);  // assume the file open for reading
     switch(scheme)
     {
     case URI_FILE:
         {
-            assert(f);          // the file must be open
+            sabassert(f);          // the file must be open
             result = fread(dest,1,maxcount,f);
             // return the number of bytes read
         }; break;
     case URI_ARG:
         {
-            assert(buffer);     // the buffer must exist
+            sabassert(buffer);     // the buffer must exist
             // do a 'strncpy' that shifts dest and bufCurr;
             // i counts the number of bytes transferred
 			char * copyChar = dest;
@@ -629,7 +651,7 @@ int DataLine::get(Sit S, char *dest,int maxcount)
             if (gotWholeDocument)
             {
                 // ugly hack: copied the following from above
-                assert(buffer);     // the buffer must exist
+                sabassert(buffer);     // the buffer must exist
 				char * copyChar = dest;
                 int i;
                 for (i = 0; 
@@ -672,13 +694,13 @@ getOutBuffer()
 DynBlock* DataLine::getOutBuffer()
 {
     // check that the output buffer exists and that we're open for write
-    assert(mode == DLMODE_WRITE && scheme == URI_ARG); 
+    sabassert(mode == DLMODE_WRITE && scheme == URI_ARG); 
     return NZ(outBuf); // -> getPointer();
 }
 
 eFlag DataLine::setURIAndClose(Sit S, const char *_uri)
 {
-    assert( mode == DLMODE_NONE );
+    sabassert( mode == DLMODE_NONE );
     mode = DLMODE_CLOSED;
     scheme = URI_ARG;
     fullUri = _uri;
