@@ -308,7 +308,7 @@ struct InstrTableItem
     instr(XSL_FALLBACK,         ELEM_II,    0, 0, at_empty),
     instr(XSL_FOR_EACH,         ELEM_I_XI,  1, 1, at_for_each),
     instr(XSL_IF,               ELEM_II,    1, 1, at_if),
-    instr(XSL_IMPORT,           ELEM_X0,    1, 1, at_import),
+    instr(XSL_IMPORT,           ELEM_T0,    1, 1, at_import),
     instr(XSL_INCLUDE,          ELEM_T0,    1, 1, at_include),
     instr(XSL_KEY,              ELEM_T0,    3, 3, at_key),
     instr(XSL_MESSAGE,          ELEM_II,    0, 1, at_message),
@@ -349,13 +349,13 @@ Vertex::~Vertex()
 
 eFlag Vertex::execute(Sit S, Context *c, Bool resolvingGlobals)
 {
-    assert(FALSE);
+    sabassert(FALSE);
     return NOT_OK;
 }
 
 eFlag Vertex::value(Sit S, DStr& ret, Context *c)
 {
-    assert(0);
+    sabassert(0);
     return NOT_OK;
 }
 
@@ -374,13 +374,13 @@ eFlag Vertex::copy(Sit S, OutputterObj& out)
   S.setCurrSAXLine(lineno); //for SAX copying - be careful
 
   OutputterObj *aux;
-  startDocument(S, aux);
+  E( startDocument(S, aux) );
 
   OutputterObj &useOut = aux ? *aux : out;
   E( startCopy(S, useOut) );
   E( endCopy(S, useOut) );
 
-  finishDocument(S);
+  E( finishDocument(S) );
 
   return OK;
 }
@@ -647,7 +647,7 @@ eFlag Daddy::value(Sit S, DStr &ret, Context *c)
 
 eFlag Daddy::checkChildren(Sit S)
 {
-    assert(!"Daddy::checkChildren()");
+    sabassert(!"Daddy::checkChildren()");
     return NOT_OK;
 }
 
@@ -936,7 +936,7 @@ eFlag Element::endCopy(Sit S, OutputterObj& out)
 eFlag Element::copy(Sit S, OutputterObj& out)
 {
   OutputterObj *aux;
-  startDocument(S, aux);
+  E( startDocument(S, aux) );
 
   OutputterObj &useOut = aux ? *aux : out;
 
@@ -946,7 +946,7 @@ eFlag Element::copy(Sit S, OutputterObj& out)
   E( contents.copy(S, useOut) );
   E( endCopy(S, useOut) );
 
-  finishDocument(S);
+  E( finishDocument(S) );
 
   return OK;
 };
@@ -1027,7 +1027,7 @@ eFlag Element::serializeSubtree(Sit S, OutputterObj &out)
 
 void Element::removeChild(Vertex *child)
 {
-    assert(child -> parent == this);
+    sabassert(child -> parent == this);
     contents.rm(child -> ordinal);
     child -> setParent(NULL);    
 }
@@ -1163,7 +1163,7 @@ eFlag Attribute::buildExpr(Sit S, Bool asTemplate, ExType ty)
 
 eFlag Attribute::execute(Sit S, Context *c, Bool resolvingGlobals)
 {
-    assert(parent);
+    sabassert(parent);
     EQName ename;
     owner.expandQ(name, ename);
     OutputterObj &out = *(NZ(S.getProcessor()) -> outputter());
@@ -1323,7 +1323,7 @@ NmSpace::~NmSpace()
 
 eFlag NmSpace::execute(Sit S, Context *c, Bool resolvingGlobals)
 {
-    assert(parent);
+    sabassert(parent);
 
     E( NZ(S.getProcessor()) -> outputter() -> 
        eventNamespace(S,
@@ -1338,7 +1338,7 @@ eFlag NmSpace::execute(Sit S, Context *c, Bool resolvingGlobals)
 eFlag NmSpace::executeSkip(Sit S, Context *c, Bool resolvingGlobals,
 			   EQName & exName, Bool aliased)
 {
-    assert(parent);
+    sabassert(parent);
 
     const Str & pStr = getOwner().dict().getKey(prefix);
     const Str & uStr = getOwner().dict().getKey(uri);
@@ -1437,7 +1437,7 @@ eFlag NSList::resolve(Sit S, Phrase &what, Bool defaultToo) const
 
 void NSList::unresolve(Phrase &what) const
 {
-    assert(what != UNDEF_PHRASE);
+    sabassert(what != UNDEF_PHRASE);
     NmSpace *currNS;
     for (int i = 0; i < number(); i++)
     {
@@ -1448,7 +1448,7 @@ void NSList::unresolve(Phrase &what) const
             return;
         }
     };
-    assert(0);
+    sabassert(0);
 }
 
 /*
@@ -1499,7 +1499,7 @@ void NSList::swallow(Sit S, NSList &other, Tree* srcTree, Tree *t)
 	}
       else
 	{
-	  assert(!srcTree);
+	  sabassert(!srcTree);
 	  p = currNS -> prefix;
 	  u = currNS -> uri;
 	}
@@ -1556,6 +1556,7 @@ eFlag NSList::executeSkip(Sit S, Context * c, Bool resolvingGlobals,
 			  EQName & exName, Bool aliased)
 {
   int i;
+  
   for (i=0; i<number(); i++)
     E( toNS((*this)[i]) -> executeSkip(S, c, resolvingGlobals,
 				 exName, aliased) );
@@ -1734,7 +1735,7 @@ XSLElement::XSLElement(Tree& owner_, QName& aqname, XSL_OP code)
 :
 Element(owner_, aqname, VT_XSL_ELEMENT_WF)
 {
-    assert(code != XSL_NONE);
+    sabassert(code != XSL_NONE);
     op = code;
 };
 
@@ -1759,7 +1760,7 @@ eFlag XSLElement::execute(Sit S, Context *c, Bool resolvingGlobals)
     //c->setCurrentNode(NULL); _cn_
 
     NodeHandle v = c -> current();
-    assert(v);
+    sabassert(v);
 
     //we store the current context to the element
     //e.g. the current() function needs it
@@ -1867,7 +1868,7 @@ eFlag XSLElement::execute(Sit S, Context *c, Bool resolvingGlobals)
 	    }
 	    else
 	    {
-		assert(x -> op == XSL_OTHERWISE);
+		sabassert(x -> op == XSL_OTHERWISE);
 		E( x -> execute(S, c, resolvingGlobals) );
 	    };
 	};
@@ -2277,7 +2278,7 @@ eFlag XSLElement::execute(Sit S, Context *c, Bool resolvingGlobals)
 	    *name = atts.find(XSLA_NAME),
 	    *match = atts.find(XSLA_MATCH),
 	    *use = atts.find(XSLA_USE);
-	assert(name && match && use && match -> expr && use -> expr);
+	sabassert(name && match && use && match -> expr && use -> expr);
 	EQName ename;
 	QName q;
 	E( setLogical(S, q, NZ(name) -> cont, FALSE) );
@@ -2451,7 +2452,7 @@ checkAtts
 eFlag XSLElement::checkAtts(Sit S)
 {
     InstrTableItem &instrData = instrTable[op];
-    assert(instrData.op == op);
+    sabassert(instrData.op == op);
     int
         attNdx,
         reqCount = 0;
@@ -2561,7 +2562,7 @@ eFlag XSLElement::checkToplevel(Sit S)
 eFlag XSLElement::checkChildren(Sit S)
 {
     InstrTableItem &iData = instrTable[op];
-    assert(iData.op == op);
+    sabassert(iData.op == op);
 
     if (!(iData.flags & ELEM_CONT) && contents.number())
         Err1(S, E_ELEM_MUST_EMPTY, xslOpNames[op]);
@@ -2610,7 +2611,7 @@ eFlag XSLElement::make1SortDef(Sit S, SortDef *&def, Context *c)
 {
     DStr temp;
 
-    assert(op == XSL_SORT);
+    sabassert(op == XSL_SORT);
     def = NULL;
     GP( SortDef ) newDef = new SortDef;
     
@@ -2671,7 +2672,7 @@ eFlag XSLElement::make1SortDef(Sit S, SortDef *&def, Context *c)
 
 eFlag XSLElement::makeSortDefs(Sit S, SortDefList &sortDefs, Context *c)
 {
-    assert(op == XSL_APPLY_TEMPLATES || op == XSL_FOR_EACH);
+    sabassert(op == XSL_APPLY_TEMPLATES || op == XSL_FOR_EACH);
 
     Vertex *child;
     for (int i = 0; i < contents.number(); i++)
@@ -2924,7 +2925,7 @@ eFlag ExtensionElement::executeEXSLTDocument(Sit S, Context *c,
   E( exsltDocGetOutputterDef(S, c, *def) );
 
   OutputDocument *doc;
-  E( proc -> createOutputDocument(S, href, doc, def.keep()) );
+  E( proc -> getOutputDocument(S, href, doc, def.keep()) );
   //we do not need to keep the definition, since document
   //initialized the outputter with it (I hope)
   
@@ -2958,7 +2959,7 @@ eFlag ExtensionElement::execute(Sit S, Context *c, Bool resolvingGlobals)
 #ifdef ENABLE_JS
     E( executeEXSLTScript(S, c, resolvingGlobals) );
 #else
-    assert(!"JSExtension not build");
+    sabassert(!"JSExtension not built");
 #endif
     break;
   case EXTE_EXSLT_DOCUMENT:
